prooftrail

Public Surface Sanitization Policy

ProofTrail keeps a governed public surface on purpose.

Public Surface

The intended public documentation surface includes:

Non-Public Surface

The following must not be tracked as live public repository content:

These directories and files are part of the non-public surface even when they exist locally for development.

Documentation Policy

Validation

Public-surface verification should include:

Generated Runtime Governance References